@@ -4,7 +4,7 @@ DISTRIB="$1"
 TDE_VERSION="$2"
 ARCH="$3"
 
-[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.0.7"
+[ -z "${TDE_VERSION}" ] && TDE_VERSION="14.0.9"
 [ -z "${ARCH}" ] && ARCH="x86_64"
 [ -x /usr/bin/podman ] && DOCKER=podman || DOCKER=docker
 
@@ -23,7 +23,7 @@ esac
 
 mkdir -p "${HOME}/rpmbuild/RPMS/RPMS${DIST}.tde-${TDE_VERSION}" "${HOME}/rpmbuild/SRPMS/SRPMS${DIST}.tde-${TDE_VERSION}"
 
-${DOCKER} run -ti --rm --privileged \
+${DOCKER} run -ti --rm \
   -h "${IMAGE}" \
   --name "${IMAGE//:/-}" \
   -v /dev/shm/${DOCKER}:/tmp:z \
